@@ -251,7 +251,7 @@ class EssClient(AbstractClient):
     def CreateFlowReminds(self, request):
         """指定需要批量催办的签署流程Id，批量催办合同，最多100个; 接口失败后返回错误信息
         注意:
-        该接口不可直接调用，需要联系运营开通后方可调用。
+        该接口不可直接调用，请联系客户经理申请使用
 
         :param request: Request instance for CreateFlowReminds.
         :type request: :class:`tencentcloud.ess.v20201111.models.CreateFlowRemindsRequest`
@@ -300,7 +300,7 @@ class EssClient(AbstractClient):
 
 
     def CreateFlowSignUrl(self, request):
-        """创建签署链接，需要联系运营人员开白后才可使用
+        """创建签署链接，请联系客户经理申请使用
 
         :param request: Request instance for CreateFlowSignUrl.
         :type request: :class:`tencentcloud.ess.v20201111.models.CreateFlowSignUrlRequest`
@@ -323,7 +323,7 @@ class EssClient(AbstractClient):
 
 
     def CreateIntegrationEmployees(self, request):
-        """创建员工
+        """创建员工,如需在此接口提醒员工实名，入参Employees的OpenId不传
 
         :param request: Request instance for CreateIntegrationEmployees.
         :type request: :class:`tencentcloud.ess.v20201111.models.CreateIntegrationEmployeesRequest`
@@ -345,6 +345,29 @@ class EssClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateIntegrationUserRoles(self, request):
+        """集成版绑定员工角色
+
+        :param request: Request instance for CreateIntegrationUserRoles.
+        :type request: :class:`tencentcloud.ess.v20201111.models.CreateIntegrationUserRolesRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.CreateIntegrationUserRolesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateIntegrationUserRoles", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateIntegrationUserRolesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateMultiFlowSignQRCode(self, request):
         """此接口（CreateMultiFlowSignQRCode）用于创建一码多扫流程签署二维码。
         适用场景：无需填写签署人信息，可通过模板id生成签署二维码，签署人可通过扫描二维码补充签署信息进行实名签署。常用于提前不知道签署人的身份信息场景，例如：劳务工招工、大批量员工入职等场景。
@@ -395,6 +418,52 @@ class EssClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreatePreparedPersonalEsign(self, request):
+        """本接口（CreatePreparedPersonalEsign）由于创建导入个人印章。
+
+        :param request: Request instance for CreatePreparedPersonalEsign.
+        :type request: :class:`tencentcloud.ess.v20201111.models.CreatePreparedPersonalEsignRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.CreatePreparedPersonalEsignResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreatePreparedPersonalEsign", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreatePreparedPersonalEsignResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateReleaseFlow(self, request):
+        """发起解除协议，主要应用场景为：基于一份已经签署的合同(签署流程)，进行解除操作。
+
+        :param request: Request instance for CreateReleaseFlow.
+        :type request: :class:`tencentcloud.ess.v20201111.models.CreateReleaseFlowRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.CreateReleaseFlowResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateReleaseFlow", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateReleaseFlowResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateSchemeUrl(self, request):
         """获取小程序跳转链接
 
@@ -497,6 +566,29 @@ class EssClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteIntegrationRoleUsers(self, request):
+        """解绑用户角色绑定关系
+
+        :param request: Request instance for DeleteIntegrationRoleUsers.
+        :type request: :class:`tencentcloud.ess.v20201111.models.DeleteIntegrationRoleUsersRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.DeleteIntegrationRoleUsersResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteIntegrationRoleUsers", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteIntegrationRoleUsersResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteSealPolicies(self, request):
         """撤销员工持有的印章权限
 
@@ -685,6 +777,29 @@ class EssClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeIntegrationRoles(self, request):
+        """查询集成版角色
+
+        :param request: Request instance for DescribeIntegrationRoles.
+        :type request: :class:`tencentcloud.ess.v20201111.models.DescribeIntegrationRolesRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.DescribeIntegrationRolesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeIntegrationRoles", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeIntegrationRolesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeOrganizationGroupOrganizations(self, request):
         """此API接口用户查询加入集团的成员企业
 
@@ -874,9 +989,33 @@ class EssClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def UpdateIntegrationEmployees(self, request):
+        """更新集成版员工信息(姓名，手机号，邮件)，用户实名后无法更改姓名与手机号
+
+        :param request: Request instance for UpdateIntegrationEmployees.
+        :type request: :class:`tencentcloud.ess.v20201111.models.UpdateIntegrationEmployeesRequest`
+        :rtype: :class:`tencentcloud.ess.v20201111.models.UpdateIntegrationEmployeesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateIntegrationEmployees", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateIntegrationEmployeesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UploadFiles(self, request):
         """此接口（UploadFiles）用于文件上传。
         适用场景：用于生成pdf资源编号（FileIds）来配合“用PDF创建流程”接口使用，使用场景可详见“用PDF创建流程”接口说明。
+        其中上传的文件，图片类型(png/jpg/jpeg)大小限制为5M，其他大小限制为60M。
         调用时需要设置Domain/接口请求域名为 file.ess.tencent.cn，并设置参数Version/版本号为2020-12-22
 
         :param request: Request instance for UploadFiles.
