@@ -312,6 +312,29 @@ class GmeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeRecordInfo(self, request):
+        """查询录制任务信息。
+
+        :param request: Request instance for DescribeRecordInfo.
+        :type request: :class:`tencentcloud.gme.v20180711.models.DescribeRecordInfoRequest`
+        :rtype: :class:`tencentcloud.gme.v20180711.models.DescribeRecordInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeRecordInfo", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeRecordInfoResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeRoomInfo(self, request):
         """获取房间内用户信息
 
@@ -359,6 +382,29 @@ class GmeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeTaskInfo(self, request):
+        """查询房间录制的详细信息
+
+        :param request: Request instance for DescribeTaskInfo.
+        :type request: :class:`tencentcloud.gme.v20180711.models.DescribeTaskInfoRequest`
+        :rtype: :class:`tencentcloud.gme.v20180711.models.DescribeTaskInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeTaskInfo", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeTaskInfoResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeUserInAndOutTime(self, request):
         """拉取用户在房间得进出时间
 
@@ -474,6 +520,29 @@ class GmeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyRecordInfo(self, request):
+        """修改录制配置信息
+
+        :param request: Request instance for ModifyRecordInfo.
+        :type request: :class:`tencentcloud.gme.v20180711.models.ModifyRecordInfoRequest`
+        :rtype: :class:`tencentcloud.gme.v20180711.models.ModifyRecordInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyRecordInfo", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyRecordInfoResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyUserMicStatus(self, request):
         """**接口作用**：此接口用于修改房间用户的麦克风状态，例如房间内用户麦克风为打开状态，可调用此接口将该用户麦克风进行关闭，关闭后即使该用户使用客户端接口 EnableMic 打开麦克风，依然无法与房间内成员通话，属于被禁言状态。该状态持续到此用户退房后失效，或者调用该接口重新打开此用户麦克风状态。
         **接口应用场景**：此接口多用于游戏业务中台或者风控后台，对一些发表不当言论的玩家进行禁言处理。
@@ -657,6 +726,52 @@ class GmeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def StartRecord(self, request):
+        """开启录制
+
+        :param request: Request instance for StartRecord.
+        :type request: :class:`tencentcloud.gme.v20180711.models.StartRecordRequest`
+        :rtype: :class:`tencentcloud.gme.v20180711.models.StartRecordResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StartRecord", params, headers=headers)
+            response = json.loads(body)
+            model = models.StartRecordResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def StopRecord(self, request):
+        """停止录制
+
+        :param request: Request instance for StopRecord.
+        :type request: :class:`tencentcloud.gme.v20180711.models.StopRecordRequest`
+        :rtype: :class:`tencentcloud.gme.v20180711.models.StopRecordResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StopRecord", params, headers=headers)
+            response = json.loads(body)
+            model = models.StopRecordResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdateScanRooms(self, request):
         """更新自定义送检房间号
 
