@@ -36,17 +36,12 @@ class StsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AssumeRole", params)
+            headers = request.headers
+            body = self.call("AssumeRole", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.AssumeRoleResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.AssumeRoleResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -64,17 +59,35 @@ class StsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AssumeRoleWithSAML", params)
+            headers = request.headers
+            body = self.call("AssumeRoleWithSAML", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.AssumeRoleWithSAMLResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.AssumeRoleWithSAMLResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def AssumeRoleWithWebIdentity(self, request):
+        """申请OIDC角色临时密钥
+
+        :param request: Request instance for AssumeRoleWithWebIdentity.
+        :type request: :class:`tencentcloud.sts.v20180813.models.AssumeRoleWithWebIdentityRequest`
+        :rtype: :class:`tencentcloud.sts.v20180813.models.AssumeRoleWithWebIdentityResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("AssumeRoleWithWebIdentity", params, headers=headers)
+            response = json.loads(body)
+            model = models.AssumeRoleWithWebIdentityResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -93,17 +106,12 @@ class StsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetCallerIdentity", params)
+            headers = request.headers
+            body = self.call("GetCallerIdentity", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.GetCallerIdentityResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.GetCallerIdentityResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -121,17 +129,12 @@ class StsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetFederationToken", params)
+            headers = request.headers
+            body = self.call("GetFederationToken", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.GetFederationTokenResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.GetFederationTokenResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -149,17 +152,12 @@ class StsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("QueryApiKey", params)
+            headers = request.headers
+            body = self.call("QueryApiKey", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.QueryApiKeyResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.QueryApiKeyResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
