@@ -275,6 +275,9 @@ RESOURCENOTFOUND_ENVIRONMENT = 'ResourceNotFound.Environment'
 # 环境角色不存在。
 RESOURCENOTFOUND_ENVIRONMENTROLE = 'ResourceNotFound.EnvironmentRole'
 
+# 实例不存在。
+RESOURCENOTFOUND_INSTANCE = 'ResourceNotFound.Instance'
+
 # 命名空间不存在。
 RESOURCENOTFOUND_NAMESPACE = 'ResourceNotFound.Namespace'
 
